package ru.ulstu.grant.model;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import org.hibernate.validator.constraints.NotEmpty;
import ru.ulstu.deadline.model.DeadlineDto;
import ru.ulstu.project.model.ProjectDto;

import java.util.List;

import static ru.ulstu.core.util.StreamApiUtils.convert;

public class GrantDto {
    private final Integer id;
    @NotEmpty
    private final String title;
    private final Grant.GrantStatus status;
    private final List<DeadlineDto> deadlines;
    private final String comment;
    private final String applicationFileName;
    private final ProjectDto project;

    @JsonCreator
    public GrantDto(@JsonProperty("id") Integer id,
                    @JsonProperty("title") String title,
                    @JsonProperty("status") Grant.GrantStatus status,
                    @JsonProperty("deadlines") List<DeadlineDto> deadlines,
                    @JsonProperty("comment") String comment,
                    @JsonProperty("project") ProjectDto project) {
        this.id = id;
        this.title = title;
        this.status = status;
        this.deadlines = deadlines;
        this.comment = comment;
        this.applicationFileName = null;
        this.project = project;
    }

    public GrantDto(Grant grant) {
        this.id = grant.getId();
        this.title = grant.getTitle();
        this.status = grant.getStatus();
        this.deadlines = convert(grant.getDeadlines(), DeadlineDto::new);
        this.comment = grant.getComment();
        this.project = grant.getProject() == null ? null : new ProjectDto(grant.getProject());
        this.applicationFileName = grant.getApplication() == null ? null : grant.getApplication().getName();
    }

    public Integer getId() {
        return id;
    }

    public String getTitle() {
        return title;
    }

    public Grant.GrantStatus getStatus() {
        return status;
    }

    public List<DeadlineDto> getDeadlines() {
        return deadlines;
    }

    public String getComment() {
        return comment;
    }

    public ProjectDto getProject() {
        return project;
    }

    public String getApplicationFileName() {
        return applicationFileName;
    }
}
